==> nuka-carousel-6.0.1.tgz: package/README.md <==
[![Nuka Carousel — Formidable, We build the modern web](https://raw.githubusercontent.com/FormidableLabs/nuka-carousel/main/Nuka-Hero.png)](https://formidable.com/open-source/nuka-carousel)

[![Maintenance Status][maintenance-image]](#maintenance-status)

Small, fast and accessibility-first React carousel library with easily customizable UI and behavior to fit your brand and site

![Nuka Carousel Animated Example](https://i.imgur.com/UwP5gle.gif)


### Install

To add `nuka-carousel` to your project run the following command in your project folder.

```bash
$ yarn add nuka-carousel
```

Come learn more and see a live demo at our [docs site](https://formidable.com/open-source/nuka-carousel)!

## Support

Have a question about react-live? Submit an issue in this repository using the
["Question" template](https://github.com/FormidableLabs/nuka-carousel/issues/new?template=question.md).

Notice something inaccurate or confusing? Feel free to [open an issue](https://github.com/FormidableLabs/nuka-carousel/issues/new/choose) or [make a pull request](https://github.com/FormidableLabs/nuka-carousel/pulls) to help improve the documentation for everyone!

The source for our docs site lives in this repo in the [`docs`](https://github.com/FormidableLabs/nuka-carousel/blob/main/docs) folder.


### Contributing

See the [Contribution Docs](CONTRIBUTING.md).

### Maintenance Status

**Active:** Formidable is actively working on this project, and we expect to continue for work for the foreseeable future. Bug reports, feature requests and pull requests are welcome.

[maintenance-image]: https://img.shields.io/badge/maintenance-active-green.svg?color=brightgreen&style=flat

==> nuka-carousel-8.0.0.tgz: package/README.md <==
[![Nuka Carousel](https://raw.githubusercontent.com/FormidableLabs/nuka-carousel/main/Nuka-Hero.png)](https://commerce.nearform.com/open-source/nuka-carousel)

[![Maintenance Status][maintenance-image]](#maintenance-status)

Small, fast and accessibility-first React carousel library with easily customizable UI and behavior to fit your brand and site

![Nuka Carousel Animated Example](https://i.imgur.com/UwP5gle.gif)


### Install

To add `nuka-carousel` to your project run the following command in your project folder.

```bash
$ yarn add nuka-carousel
```

Come learn more and see a live demo at our [docs site](https://commerce.nearform.com/open-source/nuka-carousel)!

## Support

Have a question about nuka-carousel? Submit an issue in this repository using the
["Question" template](https://github.com/FormidableLabs/nuka-carousel/issues/new?template=question.md).

Notice something inaccurate or confusing? Feel free to [open an issue](https://github.com/FormidableLabs/nuka-carousel/issues/new/choose) or [make a pull request](https://github.com/FormidableLabs/nuka-carousel/pulls) to help improve the documentation for everyone!

The source for our docs site lives in this repo in the [`docs`](https://github.com/FormidableLabs/nuka-carousel/blob/main/docs) folder.


### Contributing

See the [Contribution Docs](CONTRIBUTING.md).

### Maintenance Status

**Active:** Nearform is actively working on this project, and we expect to continue for work for the foreseeable future. Bug reports, feature requests and pull requests are welcome.

[maintenance-image]: https://img.shields.io/badge/maintenance-active-green.svg?color=brightgreen&style=flat
